@@ -36,7 +36,7 @@ import * as lambda from 'aws-cdk-lib/aws-lambda';
 
 new SnsToLambda(this, 'test-sns-lambda', {
   lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_16_X,
+    runtime: lambda.Runtime.NODEJS_20_X,
     handler: 'index.handler',
     code: lambda.Code.fromAsset(`lambda`)
   }
@@ -56,7 +56,7 @@ from constructs import Construct
 SnsToLambda(self, 'test_sns_lambda',
             lambda_function_props=_lambda.FunctionProps(
                 code=_lambda.Code.from_asset('lambda'),
-                runtime=_lambda.Runtime.PYTHON_3_9,
+                runtime=_lambda.Runtime.Python_3_11,
                 handler='index.handler'
             )
             )
@@ -75,7 +75,7 @@ import software.amazon.awsconstructs.services.snslambda.*;
 
 new SnsToLambda(this, "test-lambda-sqs-stack", new SnsToLambdaProps.Builder()
         .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_16_X)
+                .runtime(Runtime.NODEJS_20_X)
                 .code(Code.fromAsset("lambda"))
                 .handler("index.handler")
                 .build())
